@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: database.php,v 1.1.9.1.2.3 2003/12/08 02:47:24 shota Exp $
+  $Id: database.php,v 1.2 2004/01/08 04:23:41 shota Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -37,11 +37,13 @@
     }
   }
 
-function tep_db_connect($server = DB_SERVER, $username = DB_SERVER_USERNAME, $password = DB_SERVER_PASSWORD, $database = DB_DATABASE, $link = 'db_link', $port = 5432) {
+  function tep_db_connect($server = DB_SERVER, $username = DB_SERVER_USERNAME, $password = DB_SERVER_PASSWORD, $database = DB_DATABASE, $link = 'db_link', $port = 5432) {
     global $$link;
-
-    $conn_string = "host=$server port=$port dbname=$database user=$username password=$password";
-
+	if(empty($server)){
+	  $conn_string = "dbname=$database user=$username password=$password";
+	}else {
+	  $conn_string = "host=$server port=$port dbname=$database user=$username password=$password";
+	}
     if (USE_PCONNECT == 'true') {
       $$link = pg_pconnect($conn_string);
     } else {
