@@ -1,6 +1,6 @@
 <?php {
 /*
-  $Id: application_top.php,v 1.1.9.1.2.23 2003/12/02 05:40:44 shota Exp $
+  $Id: application_top.php,v 1.3 2004/01/08 09:25:31 shota Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -41,8 +41,6 @@
     }
   }
 
-// define the project version
-  define('PROJECT_VERSION', 'OpenBazaar 0.0.1');
 
 // set the type of request (secure or not)
   $request_type = (getenv('HTTPS') == 'on') ? 'SSL' : 'NONSSL';
@@ -526,13 +524,6 @@
   define('WARN_SESSION_AUTO_START', 'true');
   define('WARN_DOWNLOAD_DIRECTORY_NOT_READABLE', 'true');
 
-// check if the 'install' directory exists, and warn of its existence
-    if (WARN_INSTALL_EXISTENCE == 'true') {
-    if (file_exists(dirname($_SERVER['SCRIPT_FILENAME']) . '/install')) {
-      $messageStack->add('header', WARNING_INSTALL_DIRECTORY_EXISTS, 'warning');
-    }
-  }
-
 // check if the configure.php file is writeable
   if (WARN_CONFIG_WRITEABLE == 'true') {
     if (file_exists(dirname(DIR_FS_INCLUDES . 'configure.php')) && is_writeable(dirname(DIR_FS_INCLUDES . 'configure.php')) ) {
@@ -565,7 +556,7 @@
   }
 
   if ($messageStack->size('header') > 0) {
-    echo $messageStack->output('header');
+    $messageStack_output_header = $messageStack->output('header');
   }
 
   // for right column operation
@@ -588,6 +579,7 @@
   $t->plugins_dir[] = DIR_FS_LIB . 'tag';
   $t->assign('right_column_check', $check['count']);
   $t->assign('right_column_request_type', $request_type);
+  $t->assign('messageStack_output_header', $messageStack_output_header);
   $t->assign_by_ref('breadcrumb', $breadcrumb);
   $t->assign_by_ref('currencies', $currencies);
   $t->assign_by_ref('lng', $lng);
