@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: general.php,v 1.1.9.1.2.9 2003/10/29 06:04:45 minami Exp $
+  $Id: general.php,v 1.3 2004/01/08 08:12:21 shota Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -526,7 +526,7 @@
 	}
     $country = $address['countries_name'];
 
-    $address_format_query = tep_db_query("select address_summary from " . TABLE_ADDRESS_FORMAT . " where address_format_id = '" . $address['address_format_id'] . "'");
+    $address_format_query = tep_db_query("select address_summary from " . TABLE_ADDRESS_FORMAT . " where address_format_id = '" . (int)$address['address_format_id'] . "'");
     $address_format = tep_db_fetch_array($address_format_query);
 
 //    eval("\$address = \"{$address_format['address_summary']}\";");
@@ -1304,7 +1304,7 @@
 // for Japanese Localize
   function tep_get_fullname($firstname, $lastname) {
     $separator = ' ';
-    if ($_SESSION["language_id"] == 'japanese') {
+    if ($_SESSION["language"] == 'japanese') {
         return $lastname.$separator.$firstname;
     } else {
         return $firstname.$separator.$lastname;
