@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: english.php,v 1.1.9.1.2.3 2003/12/08 09:26:51 shota Exp $
+  $Id: english.php,v 1.2 2004/01/07 12:05:59 shota Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -136,6 +136,12 @@ define('BOX_INFORMATION_CONTACT', 'Contact Us');
 define('BOX_HEADING_TELL_A_FRIEND', 'Tell A Friend');
 define('BOX_TELL_A_FRIEND_TEXT', 'Tell someone you know about this product.');
 
+// send to mobile/pc
+define('BOX_HEADING_SEND_TO_PC', 'Send');
+define('BOX_HEADING_SEND_TO_MOBILE', 'send URL to your mobilephone');
+define('BOX_SEND_TO_PC_TEXT','Send URL to youe PC');
+define('BOX_SEND_TO_MOBILE_TEXT', 'Send URL to youe Mobilephone');
+
 // checkout procedure text
 define('CHECKOUT_BAR_DELIVERY', 'Delivery Information');
 define('CHECKOUT_BAR_PAYMENT', 'Payment Information');
