@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: japanese.php,v 1.1.2.13 2003/12/08 09:26:51 shota Exp $
+  $Id: japanese.php,v 1.2 2004/01/07 12:05:59 shota Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -140,6 +140,12 @@ define('BOX_INFORMATION_CONTACT', '䤤碌');
 define('BOX_HEADING_TELL_A_FRIEND', 'ͧãΤ餻');
 define('BOX_TELL_A_FRIEND_TEXT', 'ξʤURLͧã˥᡼뤹');
 
+// send to mobile/pc 
+define('BOX_HEADING_SEND_TO_PC', '');
+define('BOX_HEADING_SEND_TO_MOBILE', 'Ӥ˥᡼');
+define('BOX_SEND_TO_PC_TEXT','URLPC');
+define('BOX_SEND_TO_MOBILE_TEXT', 'URLӤ');
+
 // checkout procedure text
 define('CHECKOUT_BAR_DELIVERY',    'ˡ');
 define('CHECKOUT_BAR_PAYMENT',     'ʧˡ');
